# referencing the fetchers for the PyPI package

from .fanfox import Fanfox
from .mangadex import Mangadex, MangadexEN, MangadexFR
from .nh import NHentai
from .frscan import FRScan

# naver webtoons
from .naver import NaverWebtoon
from .naver import NaverBestChallenge
from .naver import NaverChallenge

# getting the enumeration
from .fetcher_enum import FetcherEnum
